"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.render = render;
exports.renderTree = renderTree;

var _server = require("react-dom/server");

var _server2 = _interopRequireDefault(_server);

var _path = require("path");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function finalizePath(node) {
  return (0, _path.join)(node.path.join("/"), node.slug, "index.html");
}

function finalizeMarkup(str) {
  return "<!DOCTYPE html>" + str;
}

function render(node, root, registry) {
  var name = node.layout || node.type;
  if (!name) {
    return false;
  }

  var comp = registry.get(name);
  if (!comp) {
    throw new Error(name + " is not a registered component");
  }

  var data = _server2.default.renderToStaticMarkup(comp({ node: node, root: root }));

  return {
    path: finalizePath(node),
    data: finalizeMarkup(data)
  };
}

function renderTree(node, root, registry) {
  var r = render(node, root, registry);
  var all = r === false ? [] : [r];
  if (node.children) {
    Object.values(node.children).forEach(function (child) {
      all = all.concat(renderTree(child, root, registry));
    });
  }
  return all;
}